%% Simplest walking model (Garcia 1998) + Actuation (Kuo 2002)
% Andrew D. Horchler, horchler @ gmail . com, Created 7-7-04
% Revision: 1.1, 5-2-16
% Modified for BWS simulation by Salil Apte, Aug 2017
% Based on:
% [1] Arthur D. Kuo "Energetics of Actively Powered Locomotion Using the Simplest Walking Model,
%   " ASME Journal of Biomedical Engineering, Vol. 124, No. 1, pp. 113-120, 2002. http://dx.doi.org/10.1115/1.1427703
%   
% [2] M. Garcia, A. Chatterjee, A. Ruina, and M. Coleman, "The Simplest Walking Model: Stability, Complexity, and Scaling," ASME Journal of
%   Biomedical Engineering, Vol. 120, No. 2, pp. 281-288, 1998. http://dx.doi.org/10.1115/1.2798313
%   
% [3] Mario W. Gomes "A Derivation of the Transisition Rule at Heelstrike which appears in the paper 'The Simplest Walking Model: Stability,
%   Complexity, and Scaling' by Garcia et al." pp. 1-3, Oct. 4, 1999.

clc
clear all

gam = 0; % flat ground
stepsize = 1.2167; 
ome = - 1.04;
stiffness = 0.08; %stiffness of hip actuation spring
amp = 0;
steps = 20; %number of steps for simulation
BWU = 0:5:100; % unloading level in steps of 5%

%% Simulated Gravity / Constant force
theta_SG = []; %where state y = [theta, theta_dot, phi, phi_dot]
theta_dot_SG = [];
phi_SG = [];
phi_dot_SG = [];

steps_SG = []; %number of steps
s_SG = []; %step size
t_SG = []; %time
tci_SG = []; %time at event i.e. foot contact
col_master_SG = []; %intermediate data to calculate stance phase
cadence_SG = []; %cadence
speed_SG = []; %mean walking speed
sls_master_SG = []; %single limb stance (or total stance) phase duration
y_err_master_SG = []; %error consequent states at beginning of every gait cycle limit cycle

for i = BWU
 [steps, t, tci, s, y] = actuatedSW_model_ConstantForce(gam,stepsize, ome, stiffness, amp, steps, i);
 theta_SG = [theta_SG , y(:,1)']; %where y = [theta, theta_dot, phi, phi_dot]
 theta_dot_SG = [theta_dot_SG , y(:,2)'];
 phi_SG = [phi_SG , y(:,3)'];
 phi_dot_SG = [phi_dot_SG , y(:,4)'];
 steps_SG = [steps_SG; steps];
 cadence_SG = [cadence_SG ; steps/t(end)];
 speed_SG = [speed_SG ; s(end)/t(end)];
 s_SG = [s_SG ; s];
 t_SG = [t_SG ; t];
 tci_SG = [tci_SG ; tci];
 col_SG = [0];
 sls_SG = [];
 y_step_SG = [];
    for j = 2:9
    col_SG = [col_SG , t(tci(j))];
    sls_SG = [sls_SG , col_SG(j) - col_SG(j-1)]; 
    y_step_SG = [y_step_SG ; y(tci(j),:)];
    end
sls_SG = mean(sls_SG);
col_master_SG = [col_master_SG; col_SG];
sls_master_SG = [sls_master_SG; sls_SG];
y_err_SG = y_step_SG(2:end,:) - y_step_SG(1:end-1,:);
y_err_SG = rms(y_err_SG);
y_err_master_SG = [y_err_master_SG;y_err_SG];
end

save('master_SG');
%% Counterweight
theta_CW = []; %where y = [theta, theta_dot, phi, phi_dot]
theta_dot_CW = [];
phi_CW = [];
phi_dot_CW = [];
steps_CW = [];
s_CW = [];
t_CW = [];
tci_CW = [];
col_master_CW = [];
cadence_CW = [];
speed_CW = [];
sls_master_CW = [];
y_err_master_CW = [];
for i = BWU
 [steps, t, tci, s, y] = actuatedSW_model_Counterweight(gam,stepsize, ome, stiffness, amp, steps, i);
 theta_CW = [theta_CW , y(:,1)']; %where y = [theta, theta_dot, phi, phi_dot]
 theta_dot_CW = [theta_dot_CW , y(:,2)'];
 phi_CW = [phi_CW , y(:,3)'];
 phi_dot_CW = [phi_dot_CW , y(:,4)'];
 steps_CW = [steps_CW; steps];
 cadence_CW = [cadence_CW ; steps/t(end)];
 speed_CW = [speed_CW ; s(end)/t(end)];
 s_CW = [s_CW ; s];
 t_CW = [t_CW ; t];
 tci_CW = [tci_CW ; tci];
 col_CW = [0];
 sls_CW = [];
 y_step_CW = [];
    for j = 2:9
    col_CW = [col_CW , t(tci(j))];
    sls_CW = [sls_CW , col_CW(j) - col_CW(j-1)]; 
    y_step_CW = [y_step_CW ; y(tci(j),:)];
    end
sls_CW = mean(sls_CW);
col_master_CW = [col_master_CW; col_CW];
sls_master_CW = [sls_master_CW; sls_CW];
y_err_CW = y_step_CW(2:end,:) - y_step_CW(1:end-1,:);
y_err_CW = rms(y_err_CW);
y_err_master_CW = [y_err_master_CW;y_err_CW];
end

save('master_CW');
%% Tuned spring

theta_TS = []; %where y = [theta, theta_dot, phi, phi_dot]
theta_dot_TS = [];
phi_TS = [];
phi_dot_TS = [];
steps_TS = [];
s_TS = [];
t_TS = [];
tci_TS = [];
col_master_TS = [];
cadence_TS = [];
speed_TS = [];
sls_master_TS = [];
y_err_master_TS = [];
for i = BWU
 [steps, t, tci, s, y] = actuatedSW_model_TunedSpring(gam,stepsize, ome, stiffness, amp, steps, i);
 theta_TS = [theta_TS , y(:,1)']; %where y = [theta, theta_dot, phi, phi_dot]
 theta_dot_TS = [theta_dot_TS , y(:,2)'];
 phi_TS = [phi_TS , y(:,3)'];
 phi_dot_TS = [phi_dot_TS , y(:,4)'];
 steps_TS = [steps_TS; steps];
 cadence_TS = [cadence_TS ; steps/t(end)];
 speed_TS = [speed_TS ; s(end)/t(end)];
 s_TS = [s_TS ; s];
 t_TS = [t_TS ; t];
 tci_TS = [tci_TS ; tci];
 col_TS = [0];
 sls_TS = [];
 y_step_TS = [];
    for j = 2:9
    col_TS = [col_TS , t(tci(j))];
    sls_TS = [sls_TS , col_TS(j) - col_TS(j-1)]; 
    y_step_TS = [y_step_TS ; y(tci(j),:)];
    end
sls_TS = mean(sls_TS);
col_master_TS = [col_master_TS; col_TS];
sls_master_TS = [sls_master_TS; sls_TS];
y_err_TS = y_step_TS(2:end,:) - y_step_TS(1:end-1,:);
y_err_TS = rms(y_err_TS);
y_err_master_TS = [y_err_master_TS;y_err_TS];
end

save('master_TS');

%% Plots 

count_SG = 5;
count_CW = 2;
count_TS = 3;
r1 = [228 26 28]./255;
b1 = [55 126 184]./255;
g1 = [77 175 74]./255;
l1 = [152 78 163]./255;
xt = 0:10:100;

%SG
C_SG = [cadence_SG(1:count_SG);zeros(length(BWU)-count_SG,1)];
WS_SG = [speed_SG(1:count_SG);zeros(length(BWU)-count_SG,1)];
SLS_SG = [sls_master_SG(1:count_SG);zeros(length(BWU)-count_SG,1)];
y_sum_SG = sum(y_err_master_SG');

%CW
C_CW = [cadence_CW(1:count_CW);zeros(length(BWU)-count_CW,1)];
WS_CW = [speed_CW(1:count_CW);zeros(length(BWU)-count_CW,1)];
SLS_CW = [sls_master_CW(1:count_CW);zeros(length(BWU)-count_CW,1)];
y_sum_CW = sum(y_err_master_CW');

%TS
C_TS = [cadence_TS(1:count_TS);zeros(length(BWU)-count_TS,1)];
WS_TS = [speed_TS(1:count_TS);zeros(length(BWU)-count_TS,1)];
SLS_TS = [sls_master_TS(1:count_TS);zeros(length(BWU)-count_TS,1)];
y_sum_TS = sum(y_err_master_TS');

%% Limit cycle
figure
figure
%plot(BWU,y_sum_SG,'color',r1,'marker','x','MarkerSize',5,'LineWidth',2)
%hold on
%plot(BWU,y_sum_CW,'color',b1,'marker','d','MarkerSize',5,'LineWidth',2)
plot(BWU,y_sum_TS,'color',g1,'marker','o','MarkerSize',5,'LineWidth',2)
grid on
grid minor
set(gca,'fontsize',32)
%xticks(xt)
ylabel('Difference between subsequent states','FontSize',32,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',32,'FontWeight','bold')
legend('Simulated gravity (SG)','Counterweight (CW)', 'Tuned spring (TS)')

%% Cadence
figure
plot(BWU,C_SG,'color',r1,'marker','x','MarkerSize',5,'LineWidth',2)
hold on
plot(BWU,C_CW,'color',b1,'marker','d','MarkerSize',5,'LineWidth',2)
plot(BWU,C_TS,'color',g1,'marker','o','MarkerSize',5,'LineWidth',2)
grid on
grid minor
set(gca,'fontsize',32)
%xticks(xt)
ylabel('Cadence','FontSize',32,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',32,'FontWeight','bold')
legend('Simulated gravity (SG)','Counterweight (CW)', 'Tuned spring (TS)')

%% Walking speed
figure
plot(BWU,WS_SG,'color',r1,'marker','x','MarkerSize',10,'LineWidth',2)
hold on
plot(BWU,WS_CW,'color',b1,'marker','d','MarkerSize',10,'LineWidth',2)
plot(BWU,WS_TS,'color',g1,'marker','o','MarkerSize',10,'LineWidth',2)
grid on
grid minor
set(gca,'fontsize',32)
%xticks(BWU)
ylabel('Walking speed','FontSize',32,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',32,'FontWeight','bold')
legend('Simulated gravity (SG)','Counterweight (CW)','Tuned spring (TS)')

%% SLS phase
figure
plot(BWU,SLS_SG,'color',r1,'marker','x','MarkerSize',10,'LineWidth',2)
hold on
plot(BWU,SLS_CW,'color',b1,'marker','d','MarkerSize',10,'LineWidth',2)
plot(BWU,SLS_TS,'color',g1,'marker','o','MarkerSize',10,'LineWidth',2)
grid on
grid minor
set(gca,'fontsize',32)
%xticks(BWU)
ylabel('SLS phase','FontSize',32,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',32,'FontWeight','bold')
legend('Simulated gravity (SG)','Counterweight (CW)','Tuned spring (TS)')



