%% Results for joint dynamics
%  SW:   Simplest walking model
%  SLIP: Spring-loaded inverted pendulum model
%  MR:   Muslce reflex model
%  Experimental data is used from this repository link: 	
%  http://dx.doi.org/10.1186/s12984-018-0380-0
%  - Salil Apte, Nov 2019

clear all
clc

r1 = [228 26 28]./255; % red    - human experimental data for treadmill healthy group
b1 = [55 126 184]./255;% blue   - human experimental data for overground healthy group
g1 = [77 175 74]./255; % green  - muscle reflex model data
o1 = [255 127 0]./255; % orange - SLIP model data
y1 = [255 255 51]./255;% yellow - simplest walking model data
l1 = [152 78 163]./255;% unused

addpath(genpath('boundedline-pkg/Inpaint_nans'))
addpath(genpath('boundedline-pkg/boundedline'))
addpath(genpath('boundedline-pkg/catuneven'))
addpath(genpath('boundedline-pkg/singlepatch'))
bws = 0:5:80;

%% HK ROM

%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
HK_MR    = [53.5125;51.2375;49.0900;49.2788;49.4725;49.5175;49.2125;48.8175;48.6125;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
HK_MR    = HK_MR/HK_MR(1);

% Human experimental data
HK_TH    = [1.0000;0.9792;0.9583;0.9369;0.9155;0.9124;0.8898;0.8618;0.8337;0.8056;0.7776;0.7402;0.7029;0.6655;0.6282;0.4964;NaN];
HK_TH_S  = [0;0.0111;0.0221;0.0322;0.0423;0.0588;0.0767;0.0867;0.0967;0.1068;0.1168;0.1201;0.1235;0.1269;0.1302;0;NaN];
HK_OH    = [1.0000;0.9802;0.9605;0.9276;0.8942;0.8523;0.8103;0.7972;0.7827;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
HK_OH_S  = [0;0.0049;0.0099;0.0325;0.0575;0.0622;0.0679;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_HK_MR_OH = sqrt(immse(HK_OH(2:4),HK_MR(2:4)));
er_HK_MR_TH = sqrt(immse(HK_TH(2:4),HK_MR(2:4)));


figure 
hold on
boundedline(bws,HK_OH,HK_OH_S,'--b',bws, HK_TH,HK_TH_S,'--r','alpha','nan', 'gap')
plot(bws,HK_MR,'-o','color',g1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 2])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Hip angle ROM','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% KK ROM

%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
KK_MR    = [67.7825;64.3850;58.6863;56.8962;55.9437;55.3738;54.8218;54.4163;54.3112;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
KK_MR    = KK_MR/KK_MR(1);

% Human experimental data
KK_TH    = [1.0000;1.0025;1.0050;0.9970;0.9890;0.9810;0.9654;0.9540;0.9426;0.9312;0.9198;0.9067;0.8937;0.8806;0.8675;0.8968;NaN];
KK_TH_S  = [0;0.0021;0.0042;0.0086;0.0213;0.0341;0.0361;0.0323;0.0285;0.0247;0.0209;0.0287;0.0365;0.0443;0.0521;0;NaN];
KK_OH    = [1.0000;0.9913;0.9826;0.9691;0.9479;0.9218;0.8956;0.8985;0.8845;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
KK_OH_S  = [0;0.0123;0.0247;0.0296;0.0266;0.0170;0.0317;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_KK_MR_OH = sqrt(immse(KK_OH(2:4),KK_MR(2:4)));
er_KK_MR_TH = sqrt(immse(KK_TH(2:4),KK_MR(2:4)));


figure 
hold on
boundedline(bws,KK_OH,KK_OH_S,'--b',bws, KK_TH,KK_TH_S,'--r','alpha','nan', 'gap')
plot(bws,KK_MR,'-o','color',g1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 2])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Knee angle ROM','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% AK ROM

%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
AK_MR    = [33.4025;30.4413;27.4288;25.9925;25.1088;24.5375;23.9063;23.4200;23.3625;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
AK_MR    = AK_MR/AK_MR(1);

% Human experimental data
AK_TH    = [1.0000;1.0064;1.0128;1.0192;1.0256;1.0210;1.0123;0.9958;0.9792;0.9627;0.9462;0.9254;0.9047;0.8840;0.8633;0.8313;NaN];
AK_TH_S  = [0;0.0130;0.0261;0.0391;0.0522;0.0752;0.0961;0.1056;0.1152;0.1249;0.1347;0.1103;0.0863;0.0630;0.0418;0.0275;NaN];
AK_OH    = [1.0000;1.0108;1.0215;1.0021;0.9668;0.9575;0.9482;1.0629;1.0395;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
AK_OH_S  = [0;0.0718;0.1436;0.1159;0.0860;0.1110;0.1428;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_AK_MR_OH = sqrt(immse(AK_OH(2:4),AK_MR(2:4)));
er_AK_MR_TH = sqrt(immse(AK_TH(2:4),AK_MR(2:4)));


figure 
hold on
boundedline(bws,AK_OH,AK_OH_S,'--b',bws, AK_TH,AK_TH_S,'--r','alpha','nan', 'gap')
plot(bws,AK_MR,'-o','color',g1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 2])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Ankle angle ROM','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% Hip ext moment

%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
HME_MR    = [1.9537;1.7375;1.4813;1.5425;1.5350;1.4938;1.4088;1.2875;1.1963;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
HME_MR    = HME_MR/HME_MR(1);

% Human experimental data
HME_TH    = [1;0.9702;0.9403;0.91045;0.8806;0.8390;0.7974;0.75590;0.7143;0.6688;0.6234;0.5780;0.5325;NaN;NaN;NaN;NaN];
HME_TH_S  = [0;0;0;0;0;0;0;0;0;0;0;0;0;NaN;NaN;NaN;NaN];
HME_OH    = [1.0000;0.9965;0.9930;0.9895;0.9902;0.9909;0.9916;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
HME_OH_S  = [0;0;0;0;0;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_HME_MR_OH = sqrt(immse(HME_OH(2:4),HME_MR(2:4)));
er_HME_MR_TH = sqrt(immse(HME_TH(2:4),HME_MR(2:4)));


figure 
hold on
boundedline(bws,HME_OH,HME_OH_S,'--b',bws, HME_TH,HME_TH_S,'--r','alpha','nan', 'gap')
plot(bws,HME_MR,'-o','color',g1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 1.5])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Hip Extension moment','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% Hip flex moment

%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
HMF_MR    = [-0.8263;-0.7313;-0.7613;-0.7888;-0.7963;-0.7788;-0.7562;-0.7250;-0.6663;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
HMF_MR    = -HMF_MR/HMF_MR(1);

% Human experimental data
HMF_TH    = [-1.0000;-0.9785;-0.9570;-0.9356;-0.9141;-0.8551;-0.7962;-0.7372;-0.6782;-0.6308;-0.5833;-0.5359;-0.4884;NaN;NaN;NaN;NaN];
HMF_TH_S  = [0;0;0;0;0;0;0;0;0;0;0;0;0;NaN;NaN;NaN;NaN];
HMF_OH    = [-1.0000;-0.9293;-0.8586;-0.7879;-0.7153;-0.6427;-0.5700;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
HMF_OH_S  = [0;0;0;0;0;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_HMF_MR_OH = sqrt(immse(HMF_OH(2:4),HMF_MR(2:4)));
er_HMF_MR_TH = sqrt(immse(HMF_TH(2:4),HMF_MR(2:4)));

figure 
hold on
boundedline(bws,HMF_OH,HMF_OH_S,'--b',bws, HMF_TH,HMF_TH_S,'--r','alpha','nan', 'gap')
plot(bws,HMF_MR,'-o','color',g1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 -1.5 0])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Hip flexion moment','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% Knee ext moment

%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
KME_MR    = [0.3825;0.2663;0.2750;0.281;0.2663;0.2425;0.2238;0.2138;0.1962;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
KME_MR    = KME_MR/KME_MR(1);

% Human experimental data
KME_TH    = [1.0000;0.9849;0.9697;0.9546;0.9394;0.9062;0.8730;0.8399;0.8067;0.8025;0.7982;0.7940;0.7898;NaN;NaN;NaN;NaN];
KME_TH_S  = [0;0;0;0;0;0;0;0;0;0;0;0;0;NaN;NaN;NaN;NaN];
KME_OH    = [1.0000;0.9633;0.9266;0.8898;0.8065;0.7232;0.6398;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
KME_OH_S  = [0;0;0;0;0;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
    
% Calculation of rmse error w.r.t to human experimental data
er_KME_MR_OH = sqrt(immse(KME_OH(2:4),KME_MR(2:4)));
er_KME_MR_TH = sqrt(immse(KME_TH(2:4),KME_MR(2:4)));


figure 
hold on
boundedline(bws,KME_OH,KME_OH_S,'--b',bws, KME_TH,KME_TH_S,'--r','alpha','nan', 'gap')
plot(bws,KME_MR,'-o','color',g1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 1.5])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Knee extension moment','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% Knee flexion moment

%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
KMF_MR    = [-0.8575;-0.8188;-0.7700;-0.7275;-0.6800;-0.6213;-0.5712;-0.5175;-0.4662;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
KMF_MR    = -KMF_MR/KMF_MR(1);

% Human experimental data
KMF_TH    = [-1.0000;-0.9363;-0.8725;-0.8087;-0.7450;-0.6863;-0.6275;-0.5687;-0.5100;-0.4184;-0.3267;-0.2351;-0.1434;NaN;NaN;NaN;NaN];
KMF_TH_S  = [0;0;0;0;0;0;0;0;0;0;0;0;0;NaN;NaN;NaN;NaN];
KMF_OH    = [-1.0000;-0.9438;-0.8876;-0.8313;-0.8755;-0.9197;-0.9639;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
KMF_OH_S  = [0;0;0;0;0;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
   
% Calculation of rmse error w.r.t to human experimental data
er_KMF_MR_OH = sqrt(immse(KMF_OH(2:4),KMF_MR(2:4)));
er_KMF_MR_TH = sqrt(immse(KMF_TH(2:4),KMF_MR(2:4)));


figure 
hold on
boundedline(bws,KMF_OH,KMF_OH_S,'--b',bws, KMF_TH,KMF_TH_S,'--r','alpha','nan', 'gap')
plot(bws,KMF_MR,'-o','color',g1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 -1.5 0])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Knee flexion moment','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% Ankle PF moment

%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
AME_MR    = [1.6800;1.6325;1.5613;1.5100;1.4600;1.4125;1.3388;1.2625;1.1850;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
AME_MR    = AME_MR/AME_MR(1);

% Human experimental data
AME_TH    = [1.0000;0.9602;0.9204;0.8806;0.8408;0.8076;0.7744;0.7413;0.7081;0.6588;0.6118;0.5647;0.5177;NaN;NaN;NaN;NaN];
AME_TH_S  = [0;0.0015;0.0030;0.0046;0.0061;0.0037;0.0014;0.0009;0.0033;0;0;0;0;NaN;NaN;NaN;NaN];
AME_OH    = [1.0000;0.9246;0.8491;0.7737;0.7245;0.6752;0.6260;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
AME_OH_S  = [0;0;0;0;0;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_AME_MR_OH = sqrt(immse(AME_OH(2:4),AME_MR(2:4)));
er_AME_MR_TH = sqrt(immse(AME_TH(2:4),AME_MR(2:4)));


figure 
hold on
boundedline(bws,AME_OH,AME_OH_S,'--b',bws, AME_TH,AME_TH_S,'--r','alpha','nan', 'gap')
plot(bws,AME_MR,'-o','color',g1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 1.5])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Ankle PF moment','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

