% Results for the sensitivity analysis
%  SW:   Simplest walking model
%  SLIP: Spring-loaded inverted pendulum model
%  MR:   Muslce reflex model
%  Experimental data is used from this repository link: 	
%  http://dx.doi.org/10.1186/s12984-018-0380-0
%  - Salil Apte, Nov 2019

clear all
clc

r1 = [228 26 28]./255; % red    - human experimental data for treadmill healthy group - mean and SD
b1 = [55 126 184]./255;% blue   - human experimental data for overground healthy group - mean and SD
g1 = [77 175 74]./255; % green  - muscle reflex model data
o1 = [255 127 0]./255; % orange - SLIP model data
y1 = [255 255 51]./255;% yellow - simplest walking model data
l1 = [152 78 163]./255;% unused

addpath(genpath('boundedline-pkg/Inpaint_nans'))
addpath(genpath('boundedline-pkg/boundedline'))
addpath(genpath('boundedline-pkg/catuneven'))
addpath(genpath('boundedline-pkg/singlepatch'))

% Generate body weight support vector for 3D stem plot
% bws = ones(165,1);
% i = 1; 
% for k = 0:5:50
%     bws(i:i+14) = bws(i:i+14)*k;
%     i = i + 15;
% end

bws = 0:5:50;

%% Simplest Walking model
% Parameter varied: Step length
% Parameters measured: Average walking speed

% Step length - input
% Original operating point is 0.7167

sl_SW = [0.2167;0.3167;0.4167;0.5167;0.6167;0.6667;0.6917;0.7167;0.7417;0.7667;0.8167;0.9167;1.0167;1.1167;1.2167];
% sl_SW = repmat(sl_SW,11,1);

% Walking speed - output
% Walking speed value is NaN for condition in which the model could not 'walk'

     
ws_SW = [NaN,NaN,1.42,1.79,2.12,2.28,2.38,2.48,2.59,2.63,NaN,NaN,NaN,3.94,4.27;
         NaN,NaN,1.44,1.78,2.13,2.31,2.39,2.47,2.56,2.60,NaN(1,5);
         NaN,NaN,1.48,1.82,2.18,2.37,2.46,2.57,NaN(1,7);
         NaN(1,15);NaN(1,15);NaN(1,15);NaN(1,15);NaN(1,15);NaN(1,15);NaN(1,15);NaN(1,15)];   
     
figure 
% stem3(bws,sl_SW,ws_SW,'filled')
surf(sl_SW,bws,ws_SW)
% hold on
% plot3([0,5,10],[0.7167,0.7167,0.7167],[0,0,0])
axis([0.35 0.8 0 15])
set(gca,'fontsize',30,'fontname','times')
xticks([0.35 0.4167 0.5167 0.6167 0.6667 0.6917 0.7167 0.7417 0.7667 0.8])
yticks([0 5 10 15])
% xticklabels({'0', '5', '10', '15'})
xlabel('Initial step Length','FontSize',30,'FontWeight','bold')
ylabel('Percentage Body weight support (BWS)','FontSize',30,'FontWeight','bold')
zlabel('Walking speed','FontSize',30,'FontWeight','bold')
title('Simplest walking model')
%% SLIP model
% Parameter varied: Initial walking speed
% Parameters measured: Average walking speed

% Initial walking speed - input
% Original operating point is 1.1185

iws_SLIP = [0.6185;0.7185;0.8185;0.9185;1.0185;1.0685;1.0935;1.1185;1.1435;1.1685;1.2185;1.3185;1.4185;1.5185;1.6185];
% iws_SLIP = repmat(iws_SLIP,11,1);

% Walking speed - output
% Walking speed value is 0 for condition in which the model could not 'walk'

ws_SLIP = [NaN(1,6),1.1607,1.1772,1.1837,NaN(1,6);
         NaN(1,5),1.1418,1.1546,1.1604,1.1636,NaN(1,6);
         NaN(1,4),1.1244,1.1448,1.1693,1.1720,NaN(1,7);
         NaN(1,4),1.1182,1.1282,1.1300,1.1637,NaN(1,7);  
         NaN(1,4),1.1205,1.1419,1.1420,NaN(1,8);                 
         NaN(1,4),1.1016,1.1366,1.1354,NaN(1,8);                 
         NaN(1,4),1.1002,1.1139,NaN(1,9);                 
         NaN(1,4),1.0768,1.1091,NaN(1,9);                 
         NaN(1,4),1.0743,NaN(1,10);                 
         NaN(1,4),1.0481,NaN(1,10);                 
         NaN(1,15)];       

figure 
% stem3(bws,iws_SLIP,ws_SLIP,'filled')
surf(iws_SLIP,bws,ws_SLIP)
% hold on
% plot3([0,25,50],[1.1185,1.1185,1.1185],[0,0,0])
% axis([0 50 0.5 2])
set(gca,'fontsize',30,'fontname','times')
xticks([1 1.0185	1.0685	1.0935	1.1185	1.1435 1.15])			
yticks([0 5 10 15 20 25 30 35 40 45 50])
yticklabels({'0', '5', '10', '15','20','25','30','35','40','45','50'})
xlabel('Initial walking speed','FontSize',30,'FontWeight','bold')
ylabel('Percentage Body weight support (BWS)','FontSize',30,'FontWeight','bold')
zlabel('Walking speed','FontSize',30,'FontWeight','bold')
title('SLIP model')

%% MR model
% Parameter varied: Initial walking speed
% Parameters measured: Average walking speed

% Initial walking speed - input
% Original operating point is 1.3

iws_MR = [0.8;0.9;1;1.1;1.2;1.25;1.275;1.3;1.325;1.35;1.4;1.5;1.6;1.7;1.8];
% iws_MR = repmat(iws_MR,11,1);

% Walking speed - output
% Walking speed value is 0 for condition in which the model could not 'walk'


ws_MR = [NaN, 1.3112, 1.3331,	1.3452,	1.3443,	1.3506,	1.3531,	1.3626,	1.3537,	1.3631,	1.3587,	1.3561,	1.379, NaN, NaN;        
         NaN, 1.2471,	1.2591,	1.2625,	1.2778,	1.2769,	1.2723,	1.2864,	1.2775,	1.2777,	1.2805,	1.2835, NaN, NaN, NaN;      
         NaN, 1.1287,	1.1392,	1.1504,	1.1488,	1.1562,	1.1553,	1.155,	1.1584,	1.1576,	1.1537,	1.1594,	1.1738,	NaN, 1.1615;
         1.0523,	1.0691,	NaN,	1.0805,	1.086,	1.0848,	1.0833,	1.0825,	1.084,	1.0848,	1.0856,	1.0938,	1.094,	NaN,	1.0952;
         0.9957, 	NaN(1,4),	1.041,	1.0397,	1.038,	1.043,	1.04,	1.0415,	1.0447	,1.0452	,1.0552	, NaN;        
         0.9757,	NaN(1,4),	0.9966,	0.9994,	1.008,	0.9985,	0.999,	0.998,	1.0014,	NaN,	1.0106,	NaN;         
         0.946,	NaN(1,4),	0.9615,	0.9596,	0.913,	NaN,	0.9662,	0.9645,	NaN,	0.9712,	0.9691,	NaN;              
         NaN(1,5),0.9186,	0.9191,	0.902,	0.9194,	0.9219, NaN, NaN,	0.9276,	NaN, NaN;                
         NaN(1,6),0.8741,	0.8543,	0.8673,	0.8724,	0.8625,	NaN, NaN, NaN,     	0.8444;            
         NaN(1,15); NaN(1,15)];       

figure 
% stem3(bws,iws_MR,ws_MR,'filled')
surf(iws_MR,bws,ws_MR)
% hold on
% plot3([0,25,50],[1.3,1.3,1.3],[0,0,0])
% axis([0 50 0.5 2])
set(gca,'fontsize',30,'fontname','times')
xticks([0.9	1	1.1	1.2	1.25	1.275	1.3	1.325 1.35 1.4	1.5	1.6])
% xticklabels({'0', '5', '10', '15','20','25','30','35','40','45','50'})
xlabel('Initial walking speed','FontSize',30,'FontWeight','bold')
ylabel('Percentage Body weight support (BWS)','FontSize',30,'FontWeight','bold')
zlabel('Walking speed','FontSize',30,'FontWeight','bold')
title('Muscle reflex model')

%% SW model

figure('Renderer', 'painters', 'Position', [10 10 900 900])
pcolor(sensitivity_SW_CF)
caxis([0 0.03]);
xticks([-1 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17])
xticklabels({'' '' '0.2167'	'0.3167'	'0.4167'	'0.5167'	'0.6167'	'0.6667'	'0.6917'	'0.7167'	'0.7417'	'0.7667'	'0.8167'	'0.9167'	'1.0167'	'1.1167'	'1.2167' ''})
yticks([1:1:21])
yticklabels({'' '0' '5' '10' ' 15' '20' '25' '30' '35' '40' '45' '50' '55' '60' '65' '70' '75' '80' '85' '90' '95'})
ylabel('BWS level (%)')
xlabel('Initial gait speed (m/s)')

figure('Renderer', 'painters', 'Position', [10 10 900 900])
pcolor(sensitivity_SW_CW)
caxis([0 0.03]);
xticks([-1 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17])
xticklabels({'' '' '0.2167'	'0.3167'	'0.4167'	'0.5167'	'0.6167'	'0.6667'	'0.6917'	'0.7167'	'0.7417'	'0.7667'	'0.8167'	'0.9167'	'1.0167'	'1.1167'	'1.2167' ''})
yticks([1:1:21])
yticklabels({'' '0' '5' '10' ' 15' '20' '25' '30' '35' '40' '45' '50' '55' '60' '65' '70' '75' '80' '85' '90' '95'})
ylabel('BWS level (%)')
xlabel('Initial gait speed (m/s)')

figure('Renderer', 'painters', 'Position', [10 10 900 900])
pcolor(sensitivity_SW_TS)
caxis([0 0.03]);
xticks([-1 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17])
xticklabels({'' '' '0.2167'	'0.3167'	'0.4167'	'0.5167'	'0.6167'	'0.6667'	'0.6917'	'0.7167'	'0.7417'	'0.7667'	'0.8167'	'0.9167'	'1.0167'	'1.1167'	'1.2167' ''})
yticks([1:1:21])
yticklabels({'' '0' '5' '10' ' 15' '20' '25' '30' '35' '40' '45' '50' '55' '60' '65' '70' '75' '80' '85' '90' '95'})
ylabel('BWS level (%)')
xlabel('Initial gait speed (m/s)')

%% SLIP model

figure('Renderer', 'painters', 'Position', [10 10 900 900])
pcolor(sensitivity_SLIP_CF)
caxis([0.8 1.3]);
xticks([-1 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17])
xticklabels({'' '' '0.6185'	'0.7185'	'0.8185'	'0.9185'	'1.0185'	'1.0685'	'1.0935'	'1.1185'	'1.1435'	'1.1685'	'1.2185'	'1.3185'	'1.4185'	'1.5185'	'1.6185' ''})
yticks([1:1:21])
yticklabels({'' '0' '5' '10' ' 15' '20' '25' '30' '35' '40' '45' '50' '55' '60' '65' '70' '75' '80' '85' '90' '95'})
ylabel('BWS level (%)')
xlabel('Initial gait speed (m/s)')

figure('Renderer', 'painters', 'Position', [10 10 900 900])
pcolor(sensitivity_SLIP_CW)
caxis([0.8 1.3]);
xticks([-1 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17])
xticklabels({'' '' '0.6185'	'0.7185'	'0.8185'	'0.9185'	'1.0185'	'1.0685'	'1.0935'	'1.1185'	'1.1435'	'1.1685'	'1.2185'	'1.3185'	'1.4185'	'1.5185'	'1.6185' ''})
yticks([1:1:21])
yticklabels({'' '0' '5' '10' ' 15' '20' '25' '30' '35' '40' '45' '50' '55' '60' '65' '70' '75' '80' '85' '90' '95'})
ylabel('BWS level (%)')
xlabel('Initial gait speed (m/s)')

figure('Renderer', 'painters', 'Position', [10 10 900 900])
pcolor(sensitivity_SLIP_TS)
caxis([0.8 1.3]);
xticks([-1 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17])
xticklabels({'' '' '0.6185'	'0.7185'	'0.8185'	'0.9185'	'1.0185'	'1.0685'	'1.0935'	'1.1185'	'1.1435'	'1.1685'	'1.2185'	'1.3185'	'1.4185'	'1.5185'	'1.6185' ''})
yticks([1:1:21])
yticklabels({'' '0' '5' '10' ' 15' '20' '25' '30' '35' '40' '45' '50' '55' '60' '65' '70' '75' '80' '85' '90' '95'})
ylabel('BWS level (%)')
xlabel('Initial gait speed (m/s)')

%% MR model

figure('Renderer', 'painters', 'Position', [10 10 900 900])
pcolor(sensitivity_MR_CF)
caxis([0.8 1.4]);
xticks([-1 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17])
xticklabels({'' '' '0.8'	'0.9'	'1'	'1.1'	'1.2'	'1.25'	'1.275'	'1.3'	'1.325'	'1.35'	'1.4'	'1.5'	'1.6'	'1.7'	'1.8' ''})
yticks([1:1:21])
yticklabels({'' '0' '5' '10' ' 15' '20' '25' '30' '35' '40' '45' '50' '55' '60' '65' '70' '75' '80' '85' '90' '95'})
ylabel('BWS level (%)')
xlabel('Initial gait speed (m/s)')

%%

figure('Renderer', 'painters', 'Position', [10 10 900 900])
pcolor(sensitivity_MR_CW)
caxis([0.8 1.4]);
xticks([-1 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17])
xticklabels({'' '' '0.8'	'0.9'	'1'	'1.1'	'1.2'	'1.25'	'1.275'	'1.3'	'1.325'	'1.35'	'1.4'	'1.5'	'1.6'	'1.7'	'1.8' ''})
yticks([1:1:21])
yticklabels({'' '0' '5' '10' ' 15' '20' '25' '30' '35' '40' '45' '50' '55' '60' '65' '70' '75' '80' '85' '90' '95'})
ylabel('BWS level (%)')
xlabel('Initial gait speed (m/s)')

%%
figure('Renderer', 'painters', 'Position', [10 10 900 900])
pcolor(sensitivity_MR_TS)
caxis([0.8 1.4]);
xticks([-1 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17])
xticklabels({'' '' '0.8'	'0.9'	'1'	'1.1'	'1.2'	'1.25'	'1.275'	'1.3'	'1.325'	'1.35'	'1.4'	'1.5'	'1.6'	'1.7'	'1.8' ''})
yticks([1:1:21])
yticklabels({'' '0' '5' '10' ' 15' '20' '25' '30' '35' '40' '45' '50' '55' '60' '65' '70' '75' '80' '85' '90' '95'})
ylabel('BWS level (%)')
xlabel('Initial gait speed (m/s)')