% Results for the spatiotemporal parameters
%  SW:   Simplest walking model
%  SLIP: Spring-loaded inverted pendulum model
%  MR:   Muslce reflex model
%  Experimental data is used from this repository link: 	
%  http://dx.doi.org/10.1186/s12984-018-0380-0
%  - Salil Apte, Nov 2019

clear all
clc

r1 = [228 26 28]./255; % red    - human experimental data for treadmill healthy group - mean and SD
b1 = [55 126 184]./255;% blue   - human experimental data for overground healthy group - mean and SD
g1 = [77 175 74]./255; % green  - muscle reflex model data
o1 = [255 127 0]./255; % orange - SLIP model data
y1 = [255 255 51]./255;% yellow - simplest walking model data
l1 = [152 78 163]./255;% unused

addpath(genpath('boundedline-pkg/Inpaint_nans'))
addpath(genpath('boundedline-pkg/boundedline'))
addpath(genpath('boundedline-pkg/catuneven'))
addpath(genpath('boundedline-pkg/singlepatch'))
bws = 0:5:80;

%% SL - Stride length

%BWU      = [    0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
SL_SW    = [1.4240;1.4426;1.4562;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN]; 
SL_SW    = SL_SW/SL_SW(1);
SL_SLIP  = [1.4126;1.4505;1.4650;1.4546;1.4896;1.4809;1.5189;1.5124;1.5383;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN]; 
SL_SLIP  = SL_SLIP/SL_SLIP(1);
SL_MR    = [1.5925;1.5737;1.6041;1.5025;1.3838;1.4412;1.4050;1.2850;1.3162;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
SL_MR    = SL_MR/SL_MR(1);

% Human experimental data
SL_TH    = [1.0000;0.9965;0.9930;0.9896;0.9863;0.9881;0.9879;1.0604;0.9867;0.9860;0.9848;0.9894;0.9940;0.9962;1.0040;0.9926;NaN];
SL_TH_S  = [0;0.0061;0.0122;0.0185;0.0248;0.0317;0.0343;0.1858;0.0394;0.0569;0.0593;0.0507;0.0423;0.0481;0.0380;0;NaN];
SL_OH    = [1.0000;0.9944;0.9888;0.9947;0.9992;0.9942;0.9893;0.9632;0.9599;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
SL_OH_S  = [0;0.0176;0.0351;0.0180;0.0379;0.0396;0.0447;0.0667;0.0712;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_SL_MR_OH = sqrt(immse(SL_OH(2:9),SL_MR(2:9)));
er_SL_MR_TH = sqrt(immse(SL_TH(2:9),SL_MR(2:9)));
er_SL_SLIP_OH = sqrt(immse(SL_OH(2:9),SL_SLIP(2:9)));
er_SL_SLIP_TH = sqrt(immse(SL_TH(2:9),SL_SLIP(2:9)));
er_SL_SW_OH = rms([abs(SL_OH(2:3) - SL_SW(2:3));1;1;1;1;1;1]); 
er_SL_SW_TH = rms([abs(SL_TH(2:3) - SL_SW(2:3));1;1;1;1;1;1]);


figure 
hold on
boundedline(bws,SL_OH,SL_OH_S,'--b',bws, SL_TH,SL_TH_S,'--r','alpha','nan', 'gap')
plot(bws,SL_MR,'-o','color',g1,'linewidth',4,'markersize',10)
plot(bws,SL_SLIP,'-o','color',o1,'linewidth',4,'markersize',10)
plot(bws,SL_SW,'-o','color',y1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 2])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Stride Length','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')
%% WS - Walking speed

%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
WS_SW     = [2.48;2.47;2.57;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN]; 
WS_SW     = WS_SW/WS_SW(1);
WS_SLIP   = [1.1772;1.1604;1.1720;1.1637;1.1420;1.1354;1.1139;1.1091;1.0743;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];  
WS_SLIP   = WS_SLIP/WS_SLIP(1);
WS_MR     = [1.3626;1.2864;1.1550;1.0825;1.0368;1.0080;0.9134;0.9020;0.8543;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
WS_MR     = WS_MR/WS_MR(1);

% Human experimental data
WS_OH    = [1.0000;0.9920;0.9697;0.9720;0.9846;0.9807;0.9750;0.9809;1.1284;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
WS_OH_S  = [0;0.0225;0.0473;0.0740;0.0876;0.0994;0.1147;0.1952;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_WS_MR_OH = sqrt(immse(WS_OH(2:9),WS_MR(2:9)));
er_WS_SLIP_OH = sqrt(immse(WS_OH(2:9),WS_SLIP(2:9)));
er_WS_SW_OH = rms([abs(WS_OH(2:3) - WS_SW(2:3));1;1;1;1;1;1]); 


figure 
hold on
boundedline(bws,WS_OH,WS_OH_S,'--b','alpha','nan', 'gap')
plot(bws,WS_MR,'-o','color',g1,'linewidth',4,'markersize',10)
plot(bws,WS_SLIP,'-o','color',o1,'linewidth',4,'markersize',10)
plot(bws,WS_SW,'-o','color',y1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 2])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Walking Speed','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')
%% C -  Cadence

%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
C_SW      = [2.774;2.754;2.815;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN]; 
C_SW      = C_SW./C_SW(1);
C_SLIP    = [1.6667;1.6000;1.6000;1.6000;1.5333;1.5333;1.4467;1.4667;1.4000;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN]; 
C_SLIP    = C_SLIP./C_SLIP(1);
C_MR      = [1.7149;1.6327;1.5038;1.4414;1.4035;1.3746;1.3536;1.4109;1.2935;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
C_MR      = C_MR./C_MR(1);

% Human experimental data
C_TH    = [1.0000;1.0040;1.0080;1.0125;1.0170;1.0127;1.0090;1.0068;1.0022;1.0439;1.0460;1.0433;1.0405;1.0377;1.0350;1.0960;NaN];
C_TH_S  = [0;0.0092;0.0185;0.0272;0.0359;0.0532;0.0610;0.0848;0.0956;0.0995;0.1048;0.1019;0.0990;0.0960;0.0930;0;NaN];
C_OH    = [1.0000;0.9976;0.9951;0.9916;0.9877;0.9802;0.9727;0.9879;0.9825;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
C_OH_S  = [0;0.0111;0.0223;0.0328;0.0429;0.0568;0.0708;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_C_MR_OH = sqrt(immse(C_OH(2:9),C_MR(2:9)));
er_C_MR_TH = sqrt(immse(C_TH(2:9),C_MR(2:9)));
er_C_SLIP_OH = sqrt(immse(C_OH(2:9),C_SLIP(2:9)));
er_C_SLIP_TH = sqrt(immse(C_TH(2:9),C_SLIP(2:9)));
er_C_SW_OH = rms([abs(C_OH(2:3) - C_SW(2:3));1;1;1;1;1;1]); 
er_C_SW_TH = rms([abs(C_TH(2:3) - C_SW(2:3));1;1;1;1;1;1]); 


figure 
hold on
boundedline(bws,C_OH,C_OH_S,'--b',bws, C_TH,C_TH_S,'--r','alpha','nan', 'gap')
plot(bws,C_MR,'-o','color',g1,'linewidth',4,'markersize',10)
plot(bws,C_SLIP,'-o','color',o1,'linewidth',4,'markersize',10)
plot(bws,C_SW,'-o','color',y1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 2])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Cadence','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')
%% SLS - Single limb stance phase (percentage of total cycle time)

%BWU      = [   0      5       10      15      20      25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
SLS_SLIP  = [21.8913;21.7673;21.6730;23.3491;23.4084;24.2992;24.0835;25.1039;26.4158;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN]; 
SLS_SLIP    = SLS_SLIP./SLS_SLIP(1);
SLS_MR    = [38.8532;40.0522;40.7436;41.1259;41.4920;41.7964;41.8347;44.6197;42.3217;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
SLS_MR    = SLS_MR./SLS_MR(1);

% Human experimental data
SLS_TH    = [1.0000;1.0348;1.0696;1.1044;1.1392;1.1739;1.1910;1.2081;1.2251;1.2422;1.2592;1.4473;1.4556;1.4639;1.4722;1.4805;NaN];
SLS_TH_S  = [0;0.0380;0.0759;0.1139;0.1518;0.1898;0.2027;0.2156;0.2285;0.2414;0.2543;0;0;0;0;0;NaN];
SLS_OH    = [1.0000;1.0084;1.0168;1.0242;1.0239;1.0326;1.0414;0.9420;0.9140;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
SLS_OH_S  = [0;0.0233;0.0466;0.0622;0.0672;0.0663;0.0657;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_SLS_MR_OH = sqrt(immse(SLS_OH(2:9),SLS_MR(2:9)));
er_SLS_MR_TH = sqrt(immse(SLS_TH(2:9),SLS_MR(2:9)));
er_SLS_SLIP_OH = sqrt(immse(SLS_OH(2:9),SLS_SLIP(2:9)));
er_SLS_SLIP_TH = sqrt(immse(SLS_TH(2:9),SLS_SLIP(2:9)));

figure 
hold on
boundedline(bws,SLS_OH,SLS_OH_S,'--b',bws, SLS_TH,SLS_TH_S,'--r','alpha','nan', 'gap')
plot(bws,SLS_MR,'-o','color',g1,'linewidth',4,'markersize',10)
plot(bws,SLS_SLIP,'-o','color',o1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 2])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('SLS gait phase','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')
%% DLS - double limb stance phase (percentage of total cycle time)

%BWU      = [    0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
DLS_SLIP  = [14.5580;13.7461;13.5165;13.2727;12.4511;12.1970;11.1981;10.8503;10.0683;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN]; 
DLS_SLIP  = DLS_SLIP./DLS_SLIP(1);
DLS_MR    = [11.0397;9.9493;9.2108;8.8736;8.5087;8.2476;8.1216;8.5536;7.6832;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
DLS_MR    = DLS_MR./DLS_MR(1);

% Human experimental data
DLS_TH    = [1.0000;0.9766;0.9532;0.9257;0.8982;0.8706;0.8532;0.8347;0.8161;0.7975;0.7789;0.7429;0.7162;0.6895;0.6628;0.6250;NaN];
DLS_TH_S  = [0;0.0251;0.0502;0.0697;0.0893;0.1090;0.1119;0.1134;0.1149;0.1164;0.1180;0.1354;0.1054;0.0755;0.0456;0;NaN];
DLS_OH    = [1.0000;0.9361;0.8722;0.8552;0.8383;0.8056;0.7729;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
DLS_OH_S  = [0;0;0;0;0;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_DLS_MR_OH = sqrt(immse(DLS_OH(2:7),DLS_MR(2:7)));
er_DLS_MR_TH = sqrt(immse(DLS_TH(2:9),DLS_MR(2:9)));
er_DLS_SLIP_OH = sqrt(immse(DLS_OH(2:7),DLS_SLIP(2:7)));
er_DLS_SLIP_TH = sqrt(immse(DLS_TH(2:9),DLS_SLIP(2:9)));

figure 
hold on
boundedline(bws,DLS_OH,DLS_OH_S,'--b',bws, DLS_TH,DLS_TH_S,'--r','alpha','nan', 'gap')
plot(bws,DLS_MR,'-o','color',g1,'linewidth',4,'markersize',10)
plot(bws,DLS_SLIP,'-o','color',o1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 2])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('DLS gait phase','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% ST - total stance phase (percentage of total cycle time)

%BWU      = [      0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
ST_SW      = [3.6055;3.6310;3.5519;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN]; 
ST_SW      = ST_SW./ST_SW(1);
ST_SLIP    = [58.3406;57.2807;56.8625;59.7909;59.2679;60.7954;59.3651;61.0581;62.8999;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN]; 
ST_SLIP    = ST_SLIP./ST_SLIP(1);
ST_MR      = [60.9325;59.9507;59.1651;58.8722;58.5084;58.2916;58.0779;61.7269;57.6820;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
ST_MR      = ST_MR./ST_MR(1);

% Human experimental data
ST_TH    = [1.0000;0.9918;0.9836;0.9749;0.9661;0.9574;0.9506;0.9629;0.9566;0.9504;0.9441;0.9381;0.9321;0.9260;0.9200;0.9068;NaN];
ST_TH_S  = [0;0.0092;0.0184;0.0270;0.0355;0.0441;0.0505;0.0507;0.0519;0.0532;0.0545;0.0517;0.0489;.0462;0.0436;0.0555;NaN];
ST_OH    = [1.0000;0.9858;0.9716;0.9609;0.9448;0.9334;0.9220;0.8801;0.8635;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
ST_OH_S  = [0;0.0188;0.0376;0.0386;0.0345;0.0288;0.0249;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_ST_MR_OH = sqrt(immse(ST_OH(2:9),ST_MR(2:9)));
er_ST_MR_TH = sqrt(immse(ST_TH(2:9),ST_MR(2:9)));
er_ST_SLIP_OH = sqrt(immse(ST_OH(2:9),ST_SLIP(2:9)));
er_ST_SLIP_TH = sqrt(immse(ST_TH(2:9),ST_SLIP(2:9)));
er_ST_SW_OH = rms([abs(ST_OH(2:3) - ST_SW(2:3));1;1;1;1;1;1]); 
er_ST_SW_TH = rms([abs(ST_TH(2:3) - ST_SW(2:3));1;1;1;1;1;1]); 


figure 
hold on
boundedline(bws,ST_OH,ST_OH_S,'--b',bws, ST_TH,ST_TH_S,'--r','alpha','nan', 'gap')
plot(bws,ST_MR,'-o','color',g1,'linewidth',4,'markersize',10)
plot(bws,ST_SLIP,'-o','color',o1,'linewidth',4,'markersize',10)
plot(bws,ST_SW,'-o','color',y1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 2])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Total stance phase','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')
