function [Fr,Str,Mod_w,delDS] = calcDynSim(speed_model_bws,cadence_model_bws,model_leglength,betamax)
% Calculate dynamic similarity parameters - Froude, Strouhal, and Modela-W
% numbers
% Salil Apte Nov 2019
clear isnan

betamax = betamax/5+1;

% Gait speed
v = speed_model_bws;
% Gait frequency
c = cadence_model_bws;
% Leg length
l = model_leglength;
% Gravity
g = 9.81;

% Froude number
Fr = (v.^2)./(g*l);

% Strouhal number
Str = l*c./v;
Str(isnan(Str))=0;

% Modela-w number
Mod_w = (2*Fr.^(-1) + Str.^2).^(-1);
Mod_w(isnan(Mod_w))=0;

% Change in dynamic similarity when considering Mod_w
x = Mod_w;
x = x./x(1);
err = abs(x(2:betamax) - x(1));
delDS = sqrt(sum(err.^2)/8)*100;
end

