% Salil Apte, Nov 2019
% Original model by Herr and Geyer 2009
% Geyer, H., & Herr, H. (2010). A muscle-reflex model that encodes principles of legged mechanics 
% produces human walking dynamics and muscle activities. 
% IEEE Transactions on neural systems and rehabilitation engineering, 18(3), 263-273.

clear all
clc

    
%Additional model parameters - distance of center of mass (COM) 
%of the body from hip joint - BWU force is applied at COM of body
d_COM = 0.35; %upper body centre of mass

cad = 1.7241; %cadence at 0% BWU
omega = cad*pi*2; 
x0_COM = -0.295;
del_y0 = 9.81/omega^2;
hori_F = 0; %horizontal force- currently set to zero

%% Constant force

BWU = 0:5:100;

t_CF = []; % time
run('nms_model_MechInit.m') % initialize mechanical parameters
run('nms_model_ControlInit.m') % initialize control parameters
vx0 = 1.3; %[m/s] 
m_total = m_HAT + 2*m_F + 2*m_S + 2*m_T; % total mass of the body


for i = BWU
     m_CF = 0.01*i*m_total;
     sim('muscleReflex_model_ConstantForce')
     t_CF = [t_CF;tout(end)];
     save(sprintf('data_CF_%d',i))
end

%% Tuned spring

BWU = 0:5:100;

t_TS = [];
run('nms_model_MechInit.m') 
run('nms_model_ControlInit.m')  
m_total = m_HAT + 2*m_F + 2*m_S + 2*m_T;
y0_COM = 1.3037; %1 + d_COM;

    for I = BWU
        K_S = 0.01*I*m_total*omega^2;
        sim('muscleReflex_model_TunedSpring')
        save(sprintf('data_TS_%d',I))
        t_TS = [t_TS;tout(end)];
    end
    

%% Plot low-pass filter output for TS model

r1 = [228 26 28]./255; 
b1 = [55 126 184]./255; 
g1 = [77 175 74]./255;  
l1 = [152 78 163]./255; 
o1 = [255 127 0]./255; 
y1 = [255 255 51]./255; 
y0 = 1.3037*ones(length(tout),1);

figure
plot(tout,filteredY,'color',b1,'linewidth',2)
hold on
plot(tout,xyzCOM(:,2),'color',r1,'linewidth',2)
plot(tout,y0t,'color',g1,'linewidth',2)
plot(tout,y0,'--','color',o1,'linewidth',2)
set(gca,'fontsize',32,'fontname','times')
xlabel('Time (s)','FontSize',36,'FontWeight','bold')
ylabel('Vertical position (m)','FontSize',36,'FontWeight','bold')
yticks([0 0.2 0.4 0.6 0.8 1 1.2 1.3037 1.4 1.6])
legend('Low-pass filter o/p','COM vertical position','Spring reference point')
grid on
grid minor
 

%% Counterweight

BWU = 0:5:100;

t_CW = [];
run('nms_model_MechInit.m') 
run('nms_model_ControlInit.m')
m_total = m_HAT + 2*m_F + 2*m_S + 2*m_T;

for i = BWU
     m_CW = 0.01*i*m_total;
     sim('muscleReflex_model_Counterweight')
     t_CW = [t_CW;tout(end)];
     save(sprintf('data_CW_%d',i))
end


