% Salil Apte, Nov 2019
% Original model by Herr and Geyer 2009
% Geyer, H., & Herr, H. (2010). A muscle-reflex model that encodes principles of legged mechanics 
% produces human walking dynamics and muscle activities. 
% IEEE Transactions on neural systems and rehabilitation engineering, 18(3), 263-273.

clear all
clc

%Additional model parameters - distance of center of mass (COM) 
%of the body from hip joint - BWU force is applied at COM of body
d_COM = 0.35; %upper body centre of mass

cad = 1.7241; %cadence at 0% BWU
omega = cad*pi*2; 
x0_COM = -0.295;
del_y0 = 9.81/omega^2;
hori_F = 0; %horizontal force- currently set to zero
VEL = 0.8:0.1:1.8;
BWU = 0:5:100;
%% Constant force


t_CF = []; % time
run('nms_model_MechInit.m') % initialize mechanical parameters
run('nms_model_ControlInit.m') % initialize control parameters
m_total = m_HAT + 2*m_F + 2*m_S + 2*m_T; % total mass of the body


for j = VEL
    vx0 = j; %[m/s] 
    for i = BWU
         m_CF = 0.01*i*m_total;
         sim('muscleReflex_model_ConstantForce')
         t_CF = [t_CF;tout(end)];
         save(sprintf('data_CF_%d%d',i,j*10))
    end
end


%% Tuned spring

t_TS = [];
run('nms_model_MechInit.m') 
run('nms_model_ControlInit.m')  
m_total = m_HAT + 2*m_F + 2*m_S + 2*m_T;
y0_COM = 1.3037; %1 + d_COM;

for j = VEL
    vx0 = j; %[m/s] 
    for i = BWU
        K_S = 0.01*i*m_total*omega^2;
        sim('muscleReflex_model_TunedSpring')
        save(sprintf('data_TS_%d_%d',i,j*1000))
        t_TS = [t_TS;tout(end)];
    end
end

%% Counterweight

t_CW = [];
run('nms_model_MechInit.m') 
run('nms_model_ControlInit.m')
m_total = m_HAT + 2*m_F + 2*m_S + 2*m_T;

for j = VEL
    vx0 = j; %[m/s]
    for i = BWU
         m_CW = 0.01*i*m_total;
         sim('muscleReflex_model_Counterweight')
         t_CW = [t_CW;tout(end)];
         save(sprintf('data_CW_%d_%d',i,j*1000))
    end
end


