%% Bipedal spring mass model (Bipedal SLIP)
% Model by Geyer et al. 2006
% Implemented by Kaur Aare Saar (kas82@cam.ac.uk), August 2016
% Modified for BWS simulation by Salil Apte, Nov 2019

clc
clear all

maxtime=10;
profile=[0 0; 1000 0]; %flat ground
parameters0 = [20 69 14000]; % angle of attack (alpha) [alpha_running  alpha_walking  stiffness]
InitialConditions=[0 1 1.1185 0]; %[x y x' y'] COM position and velocity
BWU = 0:5:100;

%% Simulated Gravity
per_master_SG = []; % Performance of the model - distance covered, number of steps, time, etc
X_master_SG = []; % States [x y x' y'] of the model, x - horizontal, y - vertical

for i = BWU
[X,performance] = SLIP_model_ConstantForce([InitialConditions, parameters0],profile,maxtime,i);
per_master_SG = [per_master_SG; performance];
X_master_SG = [X_master_SG,X];
end

x_SG = []; % horizontal position
y_SG = []; % vertical position
    for i = 1:length(X_master_SG)
       y_SG = [y_SG; X_master_SG(i).q(:,2)];
       x_SG = [x_SG; X_master_SG(i).q(:,1)];
    end
    
%% Counterweight

per_master_CW = [];
X_master_CW = [];
for i = BWU
[X,performance] = SLIP_model_Counterweight([InitialConditions, parameters0],profile,maxtime,i);
per_master_CW = [per_master_CW; performance];
X_master_CW = [X_master_CW,X];
end

x_CW = [];
y_CW = [];
    for i = 1:length(X_master_CW)
       y_CW = [y_CW; X_master_CW(i).q(:,2)];
       x_CW = [x_CW; X_master_CW(i).q(:,1)];
    end
    
%% Tuned spring

per_master_TS = [];
X_master_TS = [];
for i = BWU
[X,performance] = SLIP_model_TunedSpring([InitialConditions, parameters0],profile,maxtime,i);
per_master_TS = [per_master_TS; performance];
X_master_TS = [X_master_TS,X];
end

x_TS = [];
y_TS = [];
    for i = 1:length(X_master_TS)
       y_TS = [y_TS; X_master_TS(i).q(:,2)];
       x_TS = [x_TS; X_master_TS(i).q(:,1)];
    end
    